@@ -6,10 +6,12 @@
 
 __author__ = '''luphord'''
 __email__ = '''luphord@protonmail.com'''
-__version__ = '''0.3.2'''
+__version__ = '''0.4.0'''
 
 
+import sys
 import os
+import urllib
 from argparse import ArgumentParser, Namespace, ArgumentDefaultsHelpFormatter
 from pathlib import Path
 from xml.etree import ElementTree
@@ -26,7 +28,8 @@ base_catalog = '''<?xml version="1.0" encoding="UTF-8"?>
 
 def _iter_files(xml):
     for f in xml.find('files').findall('file'):
-        yield Path(f.get('uri').replace('file://', ''))
+        fname = urllib.parse.unquote(f.get('uri').replace('file://', ''))
+        yield Path(fname)
 
 
 class MissingFilesException(Exception):
@@ -113,6 +116,8 @@ parser.add_argument('-p', '--catalogs-base-path',
 subparsers = parser.add_subparsers(title='subcommands', dest='subcommand',
                                    help='Available subcommands')
 
+# ls subcommand
+
 ls_parser = subparsers.add_parser('ls', help='List files of a catalog')
 ls_parser.add_argument('catalog', type=Path, nargs='+')
 
@@ -126,6 +131,7 @@ def _ls(args: Namespace) -> None:
 
 ls_parser.set_defaults(func=_ls)
 
+# check subcommand
 
 check_parser = \
     subparsers.add_parser('check',
@@ -157,6 +163,27 @@ def _check(args: Namespace) -> None:
 
 check_parser.set_defaults(func=_check)
 
+# create subcommand
+
+create_parser = subparsers.add_parser('create',
+                                      help='Create a catalog by reading '
+                                           'file names from stdin')
+
+
+def _paths_from_stdin():
+    for line in sys.stdin.readlines():
+        line = line.strip()
+        if line:
+            yield Path(line).resolve()
+
+
+def _create(args: Namespace) -> None:
+    catalog = Catalog(_paths_from_stdin())
+    catalog.write(sys.stdout.buffer)
+
+
+create_parser.set_defaults(func=_create)
+
 
 def main() -> None:
     args = parser.parse_args()
